// Copyright IBM Corp. 2016. All Rights Reserved.
// Node module: apiconnect-project
// US Government Users Restricted Rights - Use, duplication or disclosure
// restricted by GSA ADP Schedule Contract with IBM Corp.

'use strict';

var debug = require('debug')('apiconnect-project:lib:project-type');
var fs = require('fs');
var path = require('path');

module.exports = getProjectType;
/**
 * Quick and dirty sync check to see if directory is a project we recognize. Currently only `loopback` is supported.
 *
 * @private
 * @param {string} path to directory to start searching.
 * @return {PathInfo}
 */
function getProjectType(searchDir) {
  // check if loopback
  var maybeLbDir = searchDir;

  // known non-loopback apps which will pass the first check
  do {
    try {
      debug('searching for %s/package.json', maybeLbDir);
      var p = require(path.join(maybeLbDir, 'package.json'));
      debug(p);
      if (
        p.dependencies && p.dependencies.hasOwnProperty('loopback') &&
        p.dependencies.hasOwnProperty('loopback-boot') && !p.hasOwnProperty('APIConnectGateway')
      ) {
        return { projectType: 'loopback', basePath: maybeLbDir, name: p.name, version: p.version };
      };

      return { projectType: 'node', basePath: maybeLbDir, name: p.name, version: p.version };
    } catch (_) {
      // ignore
    }
    try {
      if (fs.statSync(path.join(maybeLbDir, '.swiftservergenerator-project')).isFile()) {
        var config = fs.readFileSync(path.join(maybeLbDir, 'config.json'));
        var name = JSON.parse(config).appName;
        return { projectType: 'swiftserver', basePath: maybeLbDir, name: name };
      }
    } catch (_) {
      // ignore
    }
    var parentDir = path.dirname(maybeLbDir);
    if (parentDir === maybeLbDir) {
      break;
    }
    maybeLbDir = parentDir;
  } while (true);
  return { projectType: 'unknown', basePath: searchDir };
}
